Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CacheDir ¶
func CacheDir() string
CacheDir returns the fluid data directory path for caching update checks.
func CheckLatest ¶
CheckLatest queries GitHub API for the latest release. Returns (latestVersion, downloadURL, needsUpdate, error).
func ShouldCheck ¶
func ShouldCheck() bool
ShouldCheck returns true if enough time has passed since the last update check.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.